import uuid

from django.db import migrations


def get_page_uuid(page_uuids_by_slugs, slug, default_index=False):
    try:
        uuid.UUID(slug)
    except (ValueError, AttributeError):
        pass
    else:
        # it's a uuid, don't change it
        if slug in page_uuids_by_slugs.values():
            return slug

    slug = str(slug).strip('/').rsplit('/', maxsplit=1)[-1]
    if not slug and default_index:
        slug = 'index'
    return page_uuids_by_slugs.get(slug)


def forward(apps, schema_editor):
    PageSnapshot = apps.get_model('data', 'PageSnapshot')
    Page = apps.get_model('data', 'Page')
    page_uuids_by_slugs = {page.slug: str(page.uuid) for page in Page.objects.only('uuid', 'slug')}
    for snapshot in PageSnapshot.objects.all():
        changed = False

        for cell in snapshot.serialization.get('cells') or []:
            if cell.get('model') not in [
                'data.linklistcell',
                'data.menucell',
            ]:
                continue

            if cell['model'] == 'data.linklistcell':
                for link in cell.get('links') or []:
                    if link.get('model') != 'data.linkcell':
                        continue
                    if not link['fields'].get('link_page'):
                        continue
                    new_uuid = get_page_uuid(page_uuids_by_slugs, link['fields']['link_page'][0])
                    if new_uuid:
                        new_uuid = [new_uuid]
                    link['fields']['link_page'] = new_uuid
                    changed = True

            elif cell['model'] == 'data.menucell':
                if not cell['fields'].get('root_page'):
                    continue
                new_uuid = get_page_uuid(page_uuids_by_slugs, cell['fields']['root_page'][0])
                if new_uuid:
                    new_uuid = [new_uuid]
                cell['fields']['root_page'] = new_uuid
                changed = True

        if changed:
            snapshot.save()


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0064_snapshot_uuids'),
    ]

    operations = [
        migrations.RunPython(forward, reverse_code=migrations.RunPython.noop),
    ]
